# Table of Contents

- [sap-leanix-apis](<./sap-leanix-apis.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [SAP LeanIX APIs](<./SAP-LeanIX-APIs.md>)
  - [Overview](<./SAP-LeanIX-APIs/Overview.md>)
  - [REST APIs](<./SAP-LeanIX-APIs/REST-APIs.md>)
  - [GraphQL API](<./SAP-LeanIX-APIs/GraphQL-API.md>)
  - [Integration API](<./SAP-LeanIX-APIs/Integration-API.md>)
